@@ -1,13 +1,8 @@
 package Gearman::Server::Client;
-use version;
-$Gearman::Server::Client::VERSION = qv("v1.130.1");
-
-use strict;
-use warnings;
 
 =head1 NAME
 
-Gearman::Server::Client - client for gearmand
+Gearman::Server::Client
 
 =head1 NAME
 
@@ -25,39 +20,28 @@ The line-based administrative commands are documented below.
 
 =cut
 
+use strict;
 use Danga::Socket;
 use base 'Danga::Socket';
 use fields (
-
-    # { $job_name => $timeout } $timeout can be undef indicating no timeout
-    'can_do',
-    'can_do_list',
-    'can_do_iter',
-    'fast_read',
-    'fast_buffer',
-    'read_buf',
-
-    # 0/1:  they've said they're sleeping and we haven't woken them up
-    'sleeping',
-
-    # Timer for job cancellation
-    'timer',
-
-    # { $job_handle => Job }
-    'doing',
-
-    # opaque string, no whitespace.  workers give this so checker scripts
-    # can tell apart the same worker connected to multiple jobservers.
-    'client_id',
-
-    # pointer up to client's server
-    'server',
-    'options',
-    'jobs_done_since_sleep',
-);
+            'can_do',  # { $job_name => $timeout } $timeout can be undef indicating no timeout
+            'can_do_list',
+            'can_do_iter',
+            'fast_read',
+            'fast_buffer',
+            'read_buf',
+            'sleeping',   # 0/1:  they've said they're sleeping and we haven't woken them up
+            'timer', # Timer for job cancellation
+            'doing',  # { $job_handle => Job }
+            'client_id',  # opaque string, no whitespace.  workers give this so checker scripts
+                          # can tell apart the same worker connected to multiple jobservers.
+            'server',     # pointer up to client's server
+            'options',
+            'jobs_done_since_sleep',
+            );
 
 # 60k read buffer default, similar to perlbal's backend read.
-use constant READ_SIZE     => 60 * 1024;
+use constant READ_SIZE => 60 * 1024;
 use constant MAX_READ_SIZE => 512 * 1024;
 
 # Class Method:
@@ -67,35 +51,28 @@ sub new {
     $self = fields::new($self) unless ref $self;
     $self->SUPER::new($sock);
 
-    # Number of bytes to read as fast as we can (don't try to process them)
-    $self->{fast_read} = undef;
-
-    # Array of buffers used during fast read operation
-    $self->{fast_buffer} = [];
+    $self->{fast_read}   = undef; # Number of bytes to read as fast as we can (don't try to process them)
+    $self->{fast_buffer} = []; # Array of buffers used during fast read operation
     $self->{read_buf}    = '';
     $self->{sleeping}    = 0;
     $self->{can_do}      = {};
-
-    # handle -> Job
-    $self->{doing}       = {};
+    $self->{doing}       = {}; # handle -> Job
     $self->{can_do_list} = [];
-
-    # numeric iterator for where we start looking for jobs
-    $self->{can_do_iter}           = 0;
-    $self->{client_id}             = "-";
-    $self->{server}                = $server;
-    $self->{options}               = {};
+    $self->{can_do_iter} = 0;  # numeric iterator for where we start looking for jobs
+    $self->{client_id}   = "-";
+    $self->{server}      = $server;
+    $self->{options}     = {};
     $self->{jobs_done_since_sleep} = 0;
 
     return $self;
-} ## end sub new
+}
 
 sub option {
     my Gearman::Server::Client $self = shift;
     my $option = shift;
 
     return $self->{options}->{$option};
-} ## end sub option
+}
 
 sub close {
     my Gearman::Server::Client $self = shift;
@@ -114,33 +91,19 @@ sub close {
 
     # Remove self from sleepers, otherwise it will be leaked if another worker
     # for the job never connects.
-    my $sleepers      = $self->{server}{sleepers};
-    my $sleepers_list = $self->{server}{sleepers_list};
+    my $sleepers = $self->{server}{sleepers};
     for my $job (@{ $self->{can_do_list} }) {
         my $sleeping = $sleepers->{$job};
         delete $sleeping->{$self};
-
-        my $new_sleepers_list;
-        for my $client (@{ $sleepers_list->{$job} }) {
-            next unless $client;
-            push @{$new_sleepers_list}, $client unless $sleeping->{$client};
-        }
-        if ($new_sleepers_list) {
-            $self->{server}{sleepers_list}->{$job} = $new_sleepers_list;
-        }
-        else {
-            delete $self->{server}{sleepers_list}->{$job};
-        }
-
         delete $sleepers->{$job} unless %$sleeping;
-    } ## end for my $job (@{ $self->...})
+    }
 
     $self->{server}->note_disconnected_client($self);
 
     $self->CMD_reset_abilities;
 
     $self->SUPER::close;
-} ## end sub close
+}
 
 # Client
 sub event_read {
@@ -151,23 +114,22 @@ sub event_read {
 
     # Delay close till after buffers are written on EOF. If we are unable
     # to write 'err' or 'hup' will be thrown and we'll close faster.
-    return $self->write(sub { $self->close }) unless defined $bref;
+    return $self->write(sub { $self->close } ) unless defined $bref;
 
     if ($self->{fast_read}) {
-        push @{ $self->{fast_buffer} }, $$bref;
+        push @{$self->{fast_buffer}}, $$bref;
         $self->{fast_read} -= length($$bref);
 
         # If fast_read is still positive, then we need to read more data
         return if ($self->{fast_read} > 0);
 
         # Append the whole giant read buffer to our main read buffer
-        $self->{read_buf} .= join('', @{ $self->{fast_buffer} });
+        $self->{read_buf} .= join('', @{$self->{fast_buffer}});
 
         # Reset the fast read state for next time.
         $self->{fast_buffer} = [];
-        $self->{fast_read}   = undef;
-    } ## end if ($self->{fast_read})
-    else {
+        $self->{fast_read} = undef;
+    } else {
         # Exact read size length likely means we have more sitting on the
         # socket. Buffer up to half a meg in one go.
         if (length($$bref) == READ_SIZE) {
@@ -178,9 +140,9 @@ sub event_read {
                 last if (length($$cref) < READ_SIZE || $limit-- < 1);
             }
             $bref = \join('', @crefs);
-        } ## end if (length($$bref) == ...)
+        }
         $self->{read_buf} .= $$bref;
-    } ## end else [ if ($self->{fast_read})]
+    }
 
     my $found_cmd;
     do {
@@ -190,30 +152,26 @@ sub event_read {
         if ($self->{read_buf} =~ /^\0REQ(.{8,8})/s) {
             my ($cmd, $len) = unpack("NN", $1);
             if ($blen < $len + 12) {
-
                 # Start a fast read loop to get all the data we need, less
                 # what we already have in the buffer.
                 $self->{fast_read} = $len + 12 - $blen;
                 return;
-            } ## end if ($blen < $len + 12)
+            }
 
             $self->process_cmd($cmd, substr($self->{read_buf}, 12, $len));
 
             # and slide down buf:
-            $self->{read_buf} = substr($self->{read_buf}, 12 + $len);
-
-        } ## end if ($self->{read_buf} ...)
-        elsif ($self->{read_buf} =~ s/^(\w.+?)?\r?\n//) {
+            $self->{read_buf} = substr($self->{read_buf}, 12+$len);
 
+        } elsif ($self->{read_buf} =~ s/^(\w.+?)?\r?\n//) {
             # ASCII command case (useful for telnetting in)
             my $line = $1;
             $self->process_line($line);
-        } ## end elsif ($self->{read_buf} ...)
-        else {
+        } else {
             $found_cmd = 0;
         }
     } while ($found_cmd);
-} ## end sub event_read
+}
 
 sub event_write {
     my $self = shift;
@@ -234,10 +192,10 @@ sub process_line {
             $code->($self, $args);
             return;
         }
-    } ## end if ($line && $line =~ ...)
+    }
 
     return $self->err_line('unknown_command');
-} ## end sub process_line
+}
 
 =head1 Binary Protocol Structure
 
@@ -268,7 +226,7 @@ sub CMD_echo_req {
     my $blobref = shift;
 
     return $self->res_packet("echo_res", $$blobref);
-} ## end sub CMD_echo_req
+}
 
 sub CMD_work_status {
     my Gearman::Server::Client $self = shift;
@@ -276,14 +234,13 @@ sub CMD_work_status {
     my ($handle, $nu, $de) = split(/\0/, $$ar);
 
     my $job = $self->{doing}{$handle};
-    return $self->error_packet("not_worker")
-        unless $job && $job->worker == $self;
+    return $self->error_packet("not_worker") unless $job && $job->worker == $self;
 
     my $msg = Gearman::Util::pack_res_command("work_status", $$ar);
     $job->relay_to_listeners($msg);
     $job->status([$nu, $de]);
     return 1;
-} ## end sub CMD_work_status
+}
 
 sub CMD_work_complete {
     my Gearman::Server::Client $self = shift;
@@ -293,11 +250,9 @@ sub CMD_work_complete {
     my $handle = $1;
 
     my $job = delete $self->{doing}{$handle};
-    return $self->error_packet("not_worker")
-        unless $job && $job->worker == $self;
+    return $self->error_packet("not_worker") unless $job && $job->worker == $self;
 
-    my $msg = Gearman::Util::pack_res_command("work_complete",
-        join("\0", $handle, $$ar));
+    my $msg = Gearman::Util::pack_res_command("work_complete", join("\0", $handle, $$ar));
     $job->relay_to_listeners($msg);
     $job->note_finished(1);
     if (my $timer = $self->{timer}) {
@@ -306,15 +261,14 @@ sub CMD_work_complete {
     }
 
     return 1;
-} ## end sub CMD_work_complete
+}
 
 sub CMD_work_fail {
     my Gearman::Server::Client $self = shift;
-    my $ar                           = shift;
-    my $handle                       = $$ar;
-    my $job                          = delete $self->{doing}{$handle};
-    return $self->error_packet("not_worker")
-        unless $job && $job->worker == $self;
+    my $ar = shift;
+    my $handle = $$ar;
+    my $job = delete $self->{doing}{$handle};
+    return $self->error_packet("not_worker") unless $job && $job->worker == $self;
 
     my $msg = Gearman::Util::pack_res_command("work_fail", $handle);
     $job->relay_to_listeners($msg);
@@ -325,7 +279,7 @@ sub CMD_work_fail {
     }
 
     return 1;
-} ## end sub CMD_work_fail
+}
 
 sub CMD_work_exception {
     my Gearman::Server::Client $self = shift;
@@ -333,30 +287,28 @@ sub CMD_work_exception {
 
     $$ar =~ s/^(.+?)\0//;
     my $handle = $1;
-    my $job    = $self->{doing}{$handle};
+    my $job = $self->{doing}{$handle};
 
-    return $self->error_packet("not_worker")
-        unless $job && $job->worker == $self;
+    return $self->error_packet("not_worker") unless $job && $job->worker == $self;
 
-    my $msg = Gearman::Util::pack_res_command("work_exception",
-        join("\0", $handle, $$ar));
+    my $msg = Gearman::Util::pack_res_command("work_exception", join("\0", $handle, $$ar));
     $job->relay_to_option_listeners($msg, "exceptions");
 
     return 1;
-} ## end sub CMD_work_exception
+}
 
 sub CMD_pre_sleep {
     my Gearman::Server::Client $self = shift;
     $self->{'sleeping'} = 1;
     $self->{server}->on_client_sleep($self);
     return 1;
-} ## end sub CMD_pre_sleep
+}
 
 sub CMD_grab_job {
     my Gearman::Server::Client $self = shift;
 
     my $job;
-    my $can_do_size = scalar @{ $self->{can_do_list} };
+    my $can_do_size = scalar @{$self->{can_do_list}};
 
     unless ($can_do_size) {
         $self->res_packet("no_job");
@@ -376,32 +328,31 @@ sub CMD_grab_job {
             or next;
 
         $job->worker($self);
-        $self->{doing}{ $job->handle } = $job;
+        $self->{doing}{$job->handle} = $job;
 
         my $timeout = $self->{can_do}->{$job_to_grab};
         if (defined $timeout) {
-            my $timer = Danga::Socket->AddTimer(
-                $timeout,
-                sub {
-                    return $self->error_packet("not_worker")
-                        unless $job->worker == $self;
+            my $timer = Danga::Socket->AddTimer($timeout, sub {
+                return $self->error_packet("not_worker") unless $job->worker == $self;
 
-                    my $msg = Gearman::Util::pack_res_command("work_fail",
-                        $job->handle);
-                    $job->relay_to_listeners($msg);
-                    $job->note_finished(1);
-                    $job->clear_listeners;
-                    $self->{timer} = undef;
-                }
-            );
+                my $msg = Gearman::Util::pack_res_command("work_fail", $job->handle);
+                $job->relay_to_listeners($msg);
+                $job->note_finished(1);
+                $job->clear_listeners;
+                $self->{timer} = undef;
+            });
             $self->{timer} = $timer;
-        } ## end if (defined $timeout)
+        }
         return $self->res_packet("job_assign",
-            join("\0", $job->handle, $job->func, ${ $job->argref },));
-    } ## end while ($tried < $can_do_size)
+                                 join("\0",
+                                      $job->handle,
+                                      $job->func,
+                                      ${$job->argref},
+                                      ));
+    }
 
     $self->res_packet("no_job");
-} ## end sub CMD_grab_job
+}
 
 sub CMD_can_do {
     my Gearman::Server::Client $self = shift;
@@ -409,7 +360,7 @@ sub CMD_can_do {
 
     $self->{can_do}->{$$ar} = undef;
     $self->_setup_can_do_list;
-} ## end sub CMD_can_do
+}
 
 sub CMD_can_do_timeout {
     my Gearman::Server::Client $self = shift;
@@ -419,13 +370,12 @@ sub CMD_can_do_timeout {
 
     if (defined $timeout) {
         $self->{can_do}->{$task} = $timeout;
-    }
-    else {
+    } else {
         $self->{can_do}->{$task} = undef;
     }
 
     $self->_setup_can_do_list;
-} ## end sub CMD_can_do_timeout
+}
 
 sub CMD_option_req {
     my Gearman::Server::Client $self = shift;
@@ -441,7 +391,7 @@ sub CMD_option_req {
     }
 
     return $self->error_packet("unknown_option");
-} ## end sub CMD_option_req
+}
 
 sub CMD_set_client_id {
     my Gearman::Server::Client $self = shift;
@@ -450,7 +400,7 @@ sub CMD_set_client_id {
     $self->{client_id} = $$ar;
     $self->{client_id} =~ s/\s+//g;
     $self->{client_id} = "-" unless length $self->{client_id};
-} ## end sub CMD_set_client_id
+}
 
 sub CMD_cant_do {
     my Gearman::Server::Client $self = shift;
@@ -458,18 +408,18 @@ sub CMD_cant_do {
 
     delete $self->{can_do}->{$$ar};
     $self->_setup_can_do_list;
-} ## end sub CMD_cant_do
+}
 
 sub CMD_get_status {
     my Gearman::Server::Client $self = shift;
-    my $ar                           = shift;
-    my $job                          = $self->{server}->job_by_handle($$ar);
+    my $ar = shift;
+    my $job = $self->{server}->job_by_handle($$ar);
 
     # handles can't contain nulls
     return if $$ar =~ /\0/;
 
     my ($known, $running, $num, $den);
-    $known   = 0;
+    $known = 0;
     $running = 0;
     if ($job) {
         $known = 1;
@@ -477,83 +427,87 @@ sub CMD_get_status {
         if (my $stat = $job->status) {
             ($num, $den) = @$stat;
         }
-    } ## end if ($job)
+    }
 
     $num = '' unless defined $num;
     $den = '' unless defined $den;
 
-    $self->res_packet("status_res",
-        join("\0", $$ar, $known, $running, $num, $den));
-} ## end sub CMD_get_status
+    $self->res_packet("status_res", join("\0",
+                                         $$ar,
+                                         $known,
+                                         $running,
+                                         $num,
+                                         $den));
+}
 
 sub CMD_reset_abilities {
     my Gearman::Server::Client $self = shift;
 
     $self->{can_do} = {};
     $self->_setup_can_do_list;
-} ## end sub CMD_reset_abilities
+}
 
 sub _setup_can_do_list {
     my Gearman::Server::Client $self = shift;
-    $self->{can_do_list} = [keys %{ $self->{can_do} }];
+    $self->{can_do_list} = [ keys %{$self->{can_do}} ];
     $self->{can_do_iter} = 0;
 }
 
-sub CMD_submit_job    { push @_, 1; &_cmd_submit_job; }
-sub CMD_submit_job_bg { push @_, 0; &_cmd_submit_job; }
-sub CMD_submit_job_high { push @_, 1, 1; &_cmd_submit_job; }
+sub CMD_submit_job    {  push @_, 1; &_cmd_submit_job; }
+sub CMD_submit_job_bg {  push @_, 0; &_cmd_submit_job; }
+sub CMD_submit_job_high {  push @_, 1, 1; &_cmd_submit_job; }
 
 sub _cmd_submit_job {
     my Gearman::Server::Client $self = shift;
-    my $ar                           = shift;
-    my $subscribe                    = shift;
-    my $high_pri                     = shift;
+    my $ar = shift;
+    my $subscribe = shift;
+    my $high_pri = shift;
 
     return $self->error_packet("invalid_args", "No func/uniq header [$$ar].")
         unless $$ar =~ s/^(.+?)\0(.*?)\0//;
 
     my ($func, $uniq) = ($1, $2);
 
-    my $job = Gearman::Server::Job->new($self->{server}, $func, $uniq, $ar,
-        $high_pri);
+    my $job = Gearman::Server::Job->new($self->{server}, $func, $uniq, $ar, $high_pri);
 
     if ($subscribe) {
         $job->add_listener($self);
-    }
-    else {
+    } else {
         # background mode
         $job->require_listener(0);
     }
 
     $self->res_packet("job_created", $job->handle);
     $self->{server}->wake_up_sleepers($func);
-} ## end sub _cmd_submit_job
+}
 
 sub res_packet {
     my Gearman::Server::Client $self = shift;
     my ($code, $arg) = @_;
     $self->write(Gearman::Util::pack_res_command($code, $arg));
     return 1;
-} ## end sub res_packet
+}
 
 sub error_packet {
     my Gearman::Server::Client $self = shift;
     my ($code, $msg) = @_;
     $self->write(Gearman::Util::pack_res_command("error", "$code\0$msg"));
     return 0;
-} ## end sub error_packet
+}
 
 sub process_cmd {
     my Gearman::Server::Client $self = shift;
-    my $cmd                          = shift;
-    my $blob                         = shift;
+    my $cmd = shift;
+    my $blob = shift;
 
     my $cmd_name = "CMD_" . Gearman::Util::cmd_name($cmd);
-    my $ret = eval { $self->$cmd_name(\$blob); };
+    my $ret = eval {
+        $self->$cmd_name(\$blob);
+    };
     return $ret unless $@;
     warn "Error: $@\n";
     return $self->error_packet("server_error", $@);
-} ## end sub process_cmd
+}
 
 sub event_err { my $self = shift; $self->close; }
 sub event_hup { my $self = shift; $self->close; }
@@ -582,13 +536,11 @@ sub TXTCMD_workers {
 
     foreach my $cl (sort { $a->{fd} <=> $b->{fd} } $self->{server}->clients) {
         my $fd = $cl->{fd};
-        $self->write("$fd "
-                . $cl->peer_ip_string
-                . " $cl->{client_id} : @{$cl->{can_do_list}}\n");
+        $self->write("$fd " . $cl->peer_ip_string . " $cl->{client_id} : @{$cl->{can_do_list}}\n");
 
-    } ## end foreach my $cl (sort { $a->...})
+    }
     $self->write(".\n");
-} ## end sub TXTCMD_workers
+}
 
 =head2 "status"
 
@@ -619,16 +571,16 @@ A positive integer denoting the maximum possible count of workers that could be
 sub TXTCMD_status {
     my Gearman::Server::Client $self = shift;
 
-    my %funcs;    # func -> 1  (set of all funcs to display)
+    my %funcs; # func -> 1  (set of all funcs to display)
 
     # keep track of how many workers can do which functions
     my %can;
     foreach my $client ($self->{server}->clients) {
-        foreach my $func (@{ $client->{can_do_list} }) {
+        foreach my $func (@{$client->{can_do_list}}) {
             $can{$func}++;
             $funcs{$func} = 1;
         }
-    } ## end foreach my $client ($self->...)
+    }
 
     my %queued_funcs;
     my %running_funcs;
@@ -639,7 +591,7 @@ sub TXTCMD_status {
         if ($job->worker) {
             $running_funcs{$func}++;
         }
-    } ## end foreach my $job ($self->{server...})
+    }
 
     # also include queued functions (even if there aren't workers)
     # in our list of funcs to show.
@@ -649,11 +601,11 @@ sub TXTCMD_status {
         my $queued  = $queued_funcs{$func}  || 0;
         my $running = $running_funcs{$func} || 0;
         my $can     = $can{$func}           || 0;
-        $self->write("$func\t$queued\t$running\t$can\n");
-    } ## end foreach my $func (sort keys...)
+        $self->write( "$func\t$queued\t$running\t$can\n" );
+    }
 
-    $self->write(".\n");
-} ## end sub TXTCMD_status
+    $self->write( ".\n" );
+}
 
 =head2 "jobs"
 
@@ -674,8 +626,8 @@ sub TXTCMD_jobs {
     my Gearman::Server::Client $self = shift;
 
     foreach my $job ($self->{server}->jobs) {
-        my $func        = $job->func;
-        my $uniq        = $job->uniq;
+        my $func = $job->func;
+        my $uniq = $job->uniq;
         my $worker_addr = "-";
 
         if (my $worker = $job->worker) {
@@ -685,10 +637,10 @@ sub TXTCMD_jobs {
         my $listeners = $job->listeners;
 
         $self->write("$func\t$uniq\t$worker_addr\t$listeners\n");
-    } ## end foreach my $job ($self->{server...})
+    }
 
     $self->write(".\n");
-} ## end sub TXTCMD_jobs
+}
 
 =head2 "clients"
 
@@ -725,7 +677,7 @@ sub TXTCMD_clients {
             my $ent = $jobs_by_client{$client} ||= [];
             push @$ent, $job;
         }
-    } ## end foreach my $job ($self->{server...})
+    }
 
     foreach my $client ($self->{server}->clients) {
         my $client_addr = $client->peer_addr_string;
@@ -733,20 +685,20 @@ sub TXTCMD_clients {
         my $jobs = $jobs_by_client{$client} || [];
 
         foreach my $job (@$jobs) {
-            my $func        = $job->func;
-            my $uniq        = $job->uniq;
+            my $func = $job->func;
+            my $uniq = $job->uniq;
             my $worker_addr = "-";
 
             if (my $worker = $job->worker) {
                 $worker_addr = $worker->peer_addr_string;
             }
             $self->write("\t$func\t$uniq\t$worker_addr\n");
-        } ## end foreach my $job (@$jobs)
+        }
 
-    } ## end foreach my $client ($self->...)
+    }
 
     $self->write(".\n");
-} ## end sub TXTCMD_clients
+}
 
 sub TXTCMD_gladiator {
     my Gearman::Server::Client $self = shift;
@@ -756,20 +708,20 @@ sub TXTCMD_gladiator {
         my $all = Devel::Gladiator::walk_arena();
         my %ct;
         foreach my $it (@$all) {
-            $ct{ ref $it }++;
+            $ct{ref $it}++;
             if (ref $it eq "CODE") {
                 my $name = Devel::Peek::CvGV($it);
                 $ct{$name}++ if $name =~ /ANON/;
             }
-        } ## end foreach my $it (@$all)
-        $all = undef;    # required to free memory
+        }
+        $all = undef;  # required to free memory
         foreach my $n (sort { $ct{$a} <=> $ct{$b} } keys %ct) {
             next unless $ct{$n} > 1 || $args eq "all";
             $self->write(sprintf("%7d $n\n", $ct{$n}));
         }
-    } ## end if ($has_gladiator)
+    }
     $self->write(".\n");
-} ## end sub TXTCMD_gladiator
+}
 
 =head2 "maxqueue" function [max_queue_size]
 
@@ -792,7 +744,7 @@ sub TXTCMD_maxqueue {
 
     $self->{server}->set_max_queue($func, $max);
     $self->write("OK\n");
-} ## end sub TXTCMD_maxqueue
+}
 
 =head2 "shutdown" ["graceful"]
 
@@ -806,15 +758,13 @@ sub TXTCMD_shutdown {
     if ($args eq "graceful") {
         $self->write("OK\n");
         Gearmand::shutdown_graceful();
-    }
-    elsif (!$args) {
+    } elsif (! $args) {
         $self->write("OK\n");
         exit 0;
-    }
-    else {
+    } else {
         $self->err_line('unknown_args');
     }
-} ## end sub TXTCMD_shutdown
+}
 
 =head2 "version"
 
@@ -829,24 +779,22 @@ sub TXTCMD_version {
 
 sub err_line {
     my Gearman::Server::Client $self = shift;
-    my $err_code                     = shift;
-    my $err_text                     = {
-        'unknown_command# numeric iterator for where we start looking for jobl'
-            => "Unknown server command",
+    my $err_code = shift;
+    my $err_text = {
+        'unknown_command' => "Unknown server command",
         'unknown_args' => "Unknown arguments to server command",
-        'incomplete_args' =>
-            "An incomplete set of arguments was sent to this command",
+        'incomplete_args' => "An incomplete set of arguments was sent to this command",
     }->{$err_code};
 
     $self->write("ERR $err_code " . eurl($err_text) . "\r\n");
     return 0;
-} ## end sub err_line
+}
 
 sub eurl {
     my $a = $_[0];
     $a =~ s/([^a-zA-Z0-9_\,\-.\/\\\: ])/uc sprintf("%%%02x",ord($1))/eg;
     $a =~ tr/ /+/;
     return $a;
-} ## end sub eurl
+}
 
 1;
